local Proximo = Proximo
local L = LibStub("AceLocale-3.0"):GetLocale("Proximo", true)
local db

local COMBAT_EVENTS = Proximo.COMBAT_EVENTS

local spell_list = {
  --druid
  [L["Cyclone"]] = 6,
  [L["Entangling Roots"]] = 10,
  [L["Hibernate"]] = 10,
  --hunter
  [L["The Beast Within"]] = 18,
  [L["Freezing Trap Effect"]] = 10,
  --mage
  [L["Ice Block"]] = 10,
  [L["Polymorph"]] = 10,
  [L["Polymorph: Pig"]] = 10,
  [L["Polymorph: Turtle"]] = 10,
  --paladin
  [L["Divine Shield"]] = 12,
  [L["Blessing of Protection"]] = 10,
  [L["Blessing of Freedom"]] = 10,
  --priest
  [L["Pain Suppression"]] = 8,
  [L["Psychic Scream"]] = 8,
  --rogue
  [L["Sap"]] = 10,
  [L["Blind"]] = 10,
  --shaman
  [L["Bloodlust"]] = 40,
  [L["Heroism"]] = 40,
  --warlock
  [L["Fear"]] =10,
  [L["Death Coil"]] = 3,
  [L["Seduction"]] =10,
  [L["Howl of Terror"]] = 8,
  --warrior
  [L["Intimidating Shout"]] = 8,
  --generic
  [L["First Aid"]] = 8,
  [L["Evocation"]] = 8,
}

function Proximo:RegisterAuras()
  COMBAT_EVENTS["SPELL_AURA_APPLIED"] = true
  COMBAT_EVENTS["SPELL_PERIODIC_AURA_APPLIED"] = true
  COMBAT_EVENTS["SPELL_AURA_APPLIED_DOSE"] = true
  COMBAT_EVENTS["SPELL_PERIODIC_AURA_APPLIED_DOSE"] = true
  COMBAT_EVENTS["SPELL_AURA_REMOVED"] = true
  COMBAT_EVENTS["SPELL_PERIODIC_AURA_REMOVED"] = true
  COMBAT_EVENTS["SPELL_AURA_REMOVED_DOSE"] = true
  COMBAT_EVENTS["SPELL_PERIODIC_AURA_REMOVED_DOSE"] = true
  if not db then db = self.db.profile end
end

function Proximo:UnregisterAuras()
  COMBAT_EVENTS["SPELL_AURA_APPLIED"] = nil
  COMBAT_EVENTS["SPELL_PERIODIC_AURA_APPLIED"] = nil
  COMBAT_EVENTS["SPELL_AURA_APPLIED_DOSE"] = nil
  COMBAT_EVENTS["SPELL_PERIODIC_AURA_APPLIED_DOSE"] = nil
  COMBAT_EVENTS["SPELL_AURA_REMOVED"] = nil
  COMBAT_EVENTS["SPELL_PERIODIC_AURA_REMOVED"] = nil
  COMBAT_EVENTS["SPELL_AURA_REMOVED_DOSE"] = nil
  COMBAT_EVENTS["SPELL_PERIODIC_AURA_REMOVED_DOSE"] = nil
end

function Proximo:AuraApplied(unit, name, class, spell, icon)
  if spell_list[spell] then
    self:HandleAuraGain(unit, icon, spell_list[spell])
    if db.announceauragain then
      local announcement = name..": ++ "..spell.."++"
      local r, g, b = self:GetClassColor(class)
      self:SendAnnouncement(announcement, r, g, b, icon)
    end
  end
end

function Proximo:AuraRemoved(unit, name, class, spell, icon)
  if spell_list[spell] then
    self:HandleAuraFade(unit, icon)
    if db.announceaurafade then
      local announcement = name..": -- "..spell.."--"
      local r, g, b = self:GetClassColor(class)
      self:SendAnnouncement(announcement, r, g, b, icon)
    end
  end
end

function Proximo:HandleAuraGain(unit, icon, time)
  local frame = self.frame.buttons[unit].aura
  frame.icon:SetTexture(icon)
  frame.icon:SetTexCoord(0,0,0,1,1,0,1,1)
  frame.text:SetText(time)
  frame.time = time
  frame:Show()
end

function Proximo:HandleAuraFade(unit, icon)
  local frame = self.frame.buttons[unit].aura
  if frame.icon:GetTexture() == icon then
    self:AuraFade(frame)
  end
end

function Proximo:AuraFade(frame)
  frame.icon:SetTexture(nil)
  frame.text:SetText(nil)
  frame.time = nil
  frame:Hide()
end